==> haskell-lens-aeson-1.0.0.5-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lens-aeson
version: 1.0.0.5
id: lens-aeson-1.0.0.5-8b8pw5aoEEkIYxNp6hCNeV
key: lens-aeson-1.0.0.5-8b8pw5aoEEkIYxNp6hCNeV
license: MIT
copyright: Copyright (C) 2012 Paul Wilson
           Copyright (C) 2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/lens/lens-aeson/
synopsis: Law-abiding lenses for aeson
description:
    Law-abiding lenses for aeson
category: Numeric
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Aeson.Lens
abi: e0a077e6bcd1640b8fe81fdc9f39cfd0
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/lens-aeson-1.0.0.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/lens-aeson-1.0.0.5
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/lens-aeson-1.0.0.5
hs-libraries: HSlens-aeson-1.0.0.5-8b8pw5aoEEkIYxNp6hCNeV
depends:
    aeson-1.0.2.1-FrVhYmC6JHtKJ3ssqHzInY
    attoparsec-0.13.1.0-8c6XBOrZgakIL7qfHejbmf base-4.9.0.0
    bytestring-0.10.8.1 lens-4.15.1-Sq4SmlR9FU5Txy0IpGJB3
    scientific-0.3.4.12-HGDD5CZlHOuAviiRjYU5iD
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-lens-aeson/html/lens-aeson.haddock
haddock-html: /usr/share/doc/haskell-lens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lens-aeson-1.0.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lens-aeson
version: 1.0.1
id: lens-aeson-1.0.1-BJZen5ofJY28sBNN7wTMfq
key: lens-aeson-1.0.1-BJZen5ofJY28sBNN7wTMfq
license: MIT
copyright: Copyright (C) 2012 Paul Wilson
           Copyright (C) 2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/lens/lens-aeson/
synopsis: Law-abiding lenses for aeson
description:
    Law-abiding lenses for aeson
category: Numeric
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Aeson.Lens
abi: 0d7c9a69740a4f305123a0b1403dffd3
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/lens-aeson-1.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/lens-aeson-1.0.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/lens-aeson-1.0.1
hs-libraries: HSlens-aeson-1.0.1-BJZen5ofJY28sBNN7wTMfq
depends:
    aeson-1.0.2.1-FrVhYmC6JHtKJ3ssqHzInY
    attoparsec-0.13.1.0-8c6XBOrZgakIL7qfHejbmf base-4.9.0.0
    bytestring-0.10.8.1 lens-4.15.1-Sq4SmlR9FU5Txy0IpGJB3
    scientific-0.3.4.12-HGDD5CZlHOuAviiRjYU5iD
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-lens-aeson/html/lens-aeson.haddock
haddock-html: /usr/share/doc/haskell-lens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
